get_longest_dist_obs: Longest distance observations

View source: R/function_get_longest_dist_obs.R

get_longest_dist_obsR Documentation

Longest distance observations

Description

Returns the two consecutive observations of a vessel with the longest sailed distance

Usage

get_longest_dist_obs(data, ship_name)

Arguments

data

The data that has ships observations

ship_name

The name of the vessel

Value

A dataframe with two observations

Examples

# The two consecutive observations describing the longest sailed distance for the vessel 'KAROLI'
get_longest_dist_obs(data = ships, ship_name = 'KAROLI')

rabiibouhestine/ships documentation built on Oct. 7, 2022, 12:08 a.m.