get_ships_options: Get all or one ships options

Description Usage Arguments

View source: R/app_utils.R

Description

This function is to be used inside the server and UI from your app, in order to call the parameters passed to run_app().

Usage

1

Arguments

which

NULL (default), or the name of an option


siddbhatia/ships documentation built on Dec. 23, 2021, 2:20 a.m.