View source: R/function_get_longest_dist_obs.R
| get_longest_dist_obs | R Documentation |
Returns the two consecutive observations of a vessel with the longest sailed distance
get_longest_dist_obs(data, ship_name)
data |
The data that has ships observations |
ship_name |
The name of the vessel |
A dataframe with two observations
# The two consecutive observations describing the longest sailed distance for the vessel 'KAROLI' get_longest_dist_obs(data = ships, ship_name = 'KAROLI')
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.